==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-locale/lxqt-config-locale_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>المن&amp;طقة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>إعدادات مف&amp;صّلة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>الأر&amp;قام:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>الوق&amp;ت:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>ال&amp;عملة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>و&amp;حدات القياس:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>التّ&amp;جميع والفرز:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;أمثلة&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>الأرقام:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>الوقت:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>العملة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>وحدات القياس:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>لا تغيير</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>تغيّر إعدادات التّنسيق</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation>أأحفظ الإعدادات؟ (ستأخذ مفعولها في الولوج الآتي)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>إمبراطوريّة إنجليزيّة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>إمبراطوريّة أمريكيّة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>متريّة</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="38"/>
        <source>LXQt Locale Configuration</source>
        <translation>ضبط لكسكيوت للمحليّة</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="43"/>
        <source>Locale Settings</source>
        <translation>إعدادات المحليّة</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/lxqt-config-locale/lxqt-config-locale_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../../../localeconfig.ui" line="47"/>
        <source>Re&amp;gion:</source>
        <translation>المن&amp;طقة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="76"/>
        <source>De&amp;tailed Settings</source>
        <translation>إعدادات مف&amp;صّلة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="83"/>
        <source>&amp;Numbers:</source>
        <translation>الأر&amp;قام:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="112"/>
        <source>&amp;Time:</source>
        <translation>الوق&amp;ت:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="141"/>
        <source>Currenc&amp;y:</source>
        <translation>ال&amp;عملة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="170"/>
        <source>Measurement &amp;Units:</source>
        <translation>و&amp;حدات القياس:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="199"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>التّ&amp;جميع والفرز:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="238"/>
        <source>&lt;b&gt;Examples&lt;/b&gt;</source>
        <translation>&lt;b&gt;أمثلة&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="248"/>
        <source>Numbers:</source>
        <translation>الأرقام:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="268"/>
        <source>Time:</source>
        <translation>الوقت:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="288"/>
        <source>Currency:</source>
        <translation>العملة:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.ui" line="308"/>
        <source>Measurement Units:</source>
        <translation>وحدات القياس:</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="119"/>
        <source>No change</source>
        <translation>لا تغيير</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="308"/>
        <source>Format Settings Changed</source>
        <translation>تغيّر إعدادات التّنسيق</translation>
    </message>
    <message>
        <source>Save the settings ? (they will take effect the next time you log in)</source>
        <translation type="vanished">أأحفظ الإعدادات؟ (ستأخذ مفعولها في الولوج الآتي)</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="309"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="430"/>
        <source>Imperial UK</source>
        <translation>إمبراطوريّة إنجليزيّة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="434"/>
        <source>Imperial US</source>
        <translation>إمبراطوريّة أمريكيّة</translation>
    </message>
    <message>
        <location filename="../../../localeconfig.cpp" line="438"/>
        <source>Metric</source>
        <translation>متريّة</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>LXQt Locale Configuration</source>
        <translation>ضبط لكسكيوت للمحليّة</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="55"/>
        <source>Locale Settings</source>
        <translation>إعدادات المحليّة</translation>
    </message>
</context>
</TS>
